@@ -100,6 +100,9 @@ class BiogasPlant(Generator):
                 "ch4_concentration_percent",
                 self.config.ch4_concentration_percent,
             )
+            params[f"chp{idx}"].setdefault(
+                "sign_convention", self.config.sign_convention
+            )
             self.chps.append(
                 CHPCNG(params[f"chp{idx}"], init_vals[f"chp{idx}"])
             )
@@ -107,8 +110,7 @@ class BiogasPlant(Generator):
     def step(self):
         """Perform a simulation step."""
         next_state = deepcopy(self.state)
-        next_state.p_kw = self._get_setpoint()
-
+        self._check_inputs(next_state)
         self._check_gas_priority(next_state)
         self._check_gas_storage(next_state)
 
@@ -119,16 +121,20 @@ class BiogasPlant(Generator):
         self.state = next_state
         self.inputs.reset()
 
-    def _get_setpoint(self):
-        setpoint = self.inputs.p_set_kw
-        if setpoint is not None:
-            return abs(setpoint)
-
-        hour = self.inputs._now.hour
-        default = self.config.default_schedule[hour]
-        setpoint = self.config.p_max_kw * default / 100
-
-        return abs(setpoint)
+    def _check_inputs(self, nstate):
+        if self.inputs.p_set_kw is None:
+            if self.inputs.now_dt is not None:
+                default_val = self.config.default_schedule[
+                    self.inputs.now_dt.hour
+                ]
+                if self.config.use_decimal_percent:
+                    default_val *= 0.01
+                self.set_percent(default_val)
+                nstate.p_kw = self.inputs.p_set_kw
+            else:
+                nstate.p_w = 0
+        else:
+            nstate.p_kw = self.inputs.p_set_kw
 
     def _check_gas_priority(self, next_state):
         """Reset critical flags of the gas storage if feasible."""
@@ -207,15 +213,19 @@ class BiogasPlant(Generator):
             diff = abs(sum(p_kws) - next_state.p_kw)
 
             new_gas_level = (
-                next_state.gas_fill_percent * 0.01 * self.config.cap_gas_m3
+                min(100.0, next_state.gas_fill_percent)
+                * 0.01
+                * self.config.cap_gas_m3
             )
             new_gas_level -= sum(gas_cons)
-            new_gas_level = new_gas_level / self.config.cap_gas_m3 * 100
+            new_gas_percent = new_gas_level / self.config.cap_gas_m3 * 100
 
-            if new_gas_level < self.config.gas_fill_min_percent:
-                continue
-            if new_gas_level > self.config.gas_fill_max_percent:
-                continue
+            if new_gas_percent < self.config.gas_fill_min_percent:
+                if new_gas_percent < next_state.gas_fill_percent:
+                    continue
+            if new_gas_percent > self.config.gas_fill_max_percent:
+                if new_gas_percent > next_state.gas_fill_percent:
+                    continue
 
             feasibles[combi] = diff
 
@@ -225,20 +235,16 @@ class BiogasPlant(Generator):
         # Update inputs of the CHPs
         gas_level = next_state.gas_fill_percent * 0.01 * self.config.cap_gas_m3
         for chp in self.chps:
-            chp.inputs.step_size = self.inputs.step_size
-            chp.inputs.now = self.inputs._now
+            chp.set_step_size(self.inputs.step_size)
+            chp.set_now_dt(self.inputs.now_dt)
             chp.inputs.gas_critical = (
                 next_state.burn_gas or next_state.pool_gas
             )
             chp.inputs.gas_in_m3 = gas_level / len(self.chps)
 
     def _update_references(self, next_state):
-        next_state.p_kw = (
-            sum([chp.state.p_kw for chp in self.chps]) * self.config.gsign
-        )
-        next_state.p_th_kw = (
-            sum([chp.state.p_th_kw for chp in self.chps]) * self.config.gsign
-        )
+        next_state.p_kw = sum([chp.state.p_kw for chp in self.chps])
+        next_state.p_th_kw = sum([chp.state.p_th_kw for chp in self.chps])
 
         next_state.gas_cons_m3 = sum(
             [chp.state.gas_cons_m3 for chp in self.chps]
