@@ -92,21 +92,22 @@ class PVConfig(ModelConfig):
             "has_external_irradiance_model", False
         )
 
-        self.p_peak_kw = self.eta_percent / 100 * self.a_m2
-        self._default_schedule = [100 for _ in range(24)]
+        self.p_max_kw = self.eta_percent / 100 * self.a_m2
+        self.p_min_kw = 0
+        self.default_schedule = None
 
-    @property
-    def p_min_kw(self):
-        """Minimum power of PV plant in [kW]."""
-        if self.psc:
-            return -self.p_peak_kw
-        else:
-            return 0
+    # @property
+    # def p_min_kw(self):
+    #     """Minimum power of PV plant in [kW]."""
+    #     if self.psc:
+    #         return -self.p_peak_kw
+    #     else:
+    #         return 0
 
-    @property
-    def p_max_kw(self):
-        """Maximum power of PV plant in [kW]."""
-        if self.psc:
-            return 0
-        else:
-            return self.p_peak_kw
+    # @property
+    # def p_max_kw(self):
+    #     """Maximum power of PV plant in [kW]."""
+    #     if self.psc:
+    #         return 0
+    #     else:
+    #         return self.p_peak_kw
