@@ -5,6 +5,7 @@ pysimmods package.
 """
 import distutils
 from datetime import datetime, timedelta, timezone
+from typing import Any, Dict, Union
 
 import mosaik_api
 import numpy as np
@@ -263,17 +264,8 @@ class FlexibilitySimulator(mosaik_api.Simulator):
                 elif attr == "schedule":
                     for schedule in src_ids.values():
                         if schedule is not None:
-                            if not isinstance(schedule, pd.DataFrame):
-                                try:
-                                    schedule = pd.read_json(
-                                        schedule
-                                    ).tz_localize("UTC")
-                                except ValueError:
-                                    print(
-                                        "FlexMosaik: Failed to load: "
-                                        f"{schedule} (type={type(schedule)})"
-                                    )
-                                    continue
+                            schedule = deserialize_schedule(schedule)
+
                             if not schedule.empty:
                                 self.models[eid].update_schedule(schedule)
                     continue
@@ -325,5 +317,26 @@ class FlexibilitySimulator(mosaik_api.Simulator):
                 )
 
 
+def deserialize_schedule(
+    schedule: Union[pd.DataFrame, Dict[str, Any], str]
+) -> pd.DataFrame:
+    """Convert the schedule provided by mosaik to DataFrame"""
+
+    if isinstance(schedule, pd.DataFrame):
+        return schedule
+
+    if isinstance(schedule, dict):
+        # The schedule might be nested into the schedule because of an
+        # ICT simulator
+        return deserialize_schedule(list(schedule.values())[0])
+
+    if isinstance(schedule, str):
+        return pd.read_json(schedule).tz_localize("UTC")
+
+    raise ValueError(
+        f"Unsupported schedule format {type(schedule)}: {schedule}"
+    )
+
+
 if __name__ == "__main__":
     mosaik_api.start_simulation(FlexibilitySimulator())
