@@ -1,6 +1,7 @@
 """MIDAS upgrade module for the weather data simulator."""
 import logging
 
+import pandas as pd
 from midas.util.upgrade_module import UpgradeModule
 from pysimmods.buffer.batterysim.presets import battery_presets
 from pysimmods.consumer.hvacsim.presets import hvac_preset
@@ -11,6 +12,8 @@ from pysimmods.generator.pvsystemsim.presets import pv_preset
 
 from mosaik.exceptions import ScenarioError
 
+from .analysis.analysis import analyze
+
 LOG = logging.getLogger(__name__)
 
 
@@ -449,6 +452,28 @@ class PysimmodsModule(UpgradeModule):
             self.scenario.actuators.append(actuator)
             LOG.debug("Created actuator entry %s.", actuator)
 
+    def download(
+        self,
+        data_path: str,
+        tmp_path: str,
+        load_if_necessary: bool,
+        force: bool,
+    ):
+        # No downloads
+        pass
+
+    def analyze(
+        self,
+        name: str,
+        data: pd.HDFStore,
+        output_folder: str,
+        start: int,
+        end: int,
+        step_size: int,
+        full: bool,
+    ):
+        analyze(name, data, output_folder, start, end, step_size, full)
+
 
 def create_default_mapping():
     return {
