@@ -15,7 +15,10 @@ class ScheduleModel:
     """
 
     def __init__(
-        self, model: Model, unit: str = "kw", priorize_setpoint: bool = False
+        self,
+        model: Model,
+        unit: str = "kw",
+        priorize_setpoint: bool = False,
     ) -> None:
 
         self._model = model
@@ -70,7 +73,10 @@ class ScheduleModel:
             self._now_dt = self._model.inputs.now_dt
         if self.schedule is None:
             self.schedule = Schedule(
-                self._pname, self._qname, self._now_dt, self._step_size
+                self._pname,
+                self._qname,
+                self._now_dt,
+                self._step_size,
             )
             self.schedule.init()
         if self.schedule.step_size is None:
@@ -130,6 +136,9 @@ class ScheduleModel:
     def set_percent(self, percentage):
         self._model.set_percent(percentage)
 
+    def get_now_dt(self):
+        return self._model.get_now_dt()
+
     def get_p_kw(self):
         return self._model.get_p_kw()
 
